@@ -29,30 +29,25 @@
 #include "enums.h"
 #include "ImagePreviewWidget.h"
 #include <QCheckBox>
-#include <kdialog.h>
+#include <QDialog>
 #include "config-kpa-kgeomap.h"
 
-class QStackedWidget;
-class KActionCollection;
-class QMoveEvent;
-class QResizeEvent;
-class QCloseEvent;
-class KComboBox;
-class KTextEdit;
 class DockWidget;
-class QDockWidget;
-class QTimeEdit;
-class QMainWindow;
-class QSplitter;
-class KPushButton;
+class KActionCollection;
+class KComboBox;
 class KLineEdit;
-class KPushButton;
-class QProgressBar;
 class KRatingWidget;
-
-#ifdef HAVE_KGEOMAP
+class KTextEdit;
+class QCloseEvent;
+class QDockWidget;
+class QMainWindow;
+class QMoveEvent;
+class QProgressBar;
 class QPushButton;
-#endif
+class QResizeEvent;
+class QSplitter;
+class QStackedWidget;
+class QTimeEdit;
 
 namespace Viewer
 {
@@ -72,11 +67,11 @@ namespace Map
 namespace AnnotationDialog
 {
 class ImagePreview;
-class KDateEdit;
+class DateEdit;
 class ShortCutManager;
 class ResizableFrame;
 
-class Dialog :public KDialog {
+class Dialog :public QDialog {
     Q_OBJECT
 public:
     explicit Dialog( QWidget* parent );
@@ -167,17 +162,17 @@ private:
     // Widgets
     QMainWindow* m_dockWindow;
     KLineEdit* m_imageLabel;
-    KDateEdit* m_startDate;
-    KDateEdit* m_endDate;
+    DateEdit* m_startDate;
+    DateEdit* m_endDate;
     QLabel* m_endDateLabel;
     QLabel* m_imageFilePatternLabel;
     KLineEdit* m_imageFilePattern;
 
     ImagePreviewWidget* m_preview;
-    KPushButton* m_revertBut;
-    KPushButton* m_clearBut;
-    KPushButton* m_okBut;
-    KPushButton* m_continueLaterBut;
+    QPushButton* m_revertBut;
+    QPushButton* m_clearBut;
+    QPushButton* m_okBut;
+    QPushButton* m_continueLaterBut;
     KTextEdit* m_description;
     QTimeEdit* m_time;
     QLabel* m_timeLabel;
