@@ -20,7 +20,7 @@
 #include <DB/ImageDB.h>
 #include "DragableTreeWidget.h"
 #include "DragItemInfo.h"
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <QDropEvent>
 #include "DB/CategoryItem.h"
