@@ -1,5 +1,7 @@
 #include "FastDir.h"
-#include <kde_file.h>
+
+#include <QFile>
+
 #include <sys/types.h>
 #include <dirent.h>
 #include <stdio.h>
@@ -15,20 +17,24 @@ QStringList DB::FastDir::entryList() const
     QStringList answer;
     DIR *dir;
     dirent *file;
-    dir = opendir( QFile::encodeName(m_path) );
+    QByteArray path = QFile::encodeName(m_path);
+    dir = opendir( path.constData() );
     if ( !dir )
-    return answer; // cannot read the directory
+        return answer; // cannot read the directory
 
 #if defined(QT_THREAD_SUPPORT) && defined(_POSIX_THREAD_SAFE_FUNCTIONS) && !defined(Q_OS_CYGWIN)
+    // ZaJ (2016-03-23): while porting to Qt5/KF5, this code-path is disabled on my system
+    //     I don't want to touch this right now since I can't verify correctness in any way.
     union dirent_buf {
-    struct KDE_struct_dirent mt_file;
-    char b[sizeof(struct dirent) + MAXNAMLEN + 1];
+        struct KDE_struct_dirent mt_file;
+        char b[sizeof(struct dirent) + MAXNAMLEN + 1];
     } *u = new union dirent_buf;
     while ( readdir_r(dir, &(u->mt_file), &file ) == 0 && file )
 #else
-    while ( (file = KDE_readdir(dir)) )
+    // FIXME: use 64bit versions of readdir and dirent?
+    while ( (file = readdir(dir)) )
 #endif // QT_THREAD_SUPPORT && _POSIX_THREAD_SAFE_FUNCTIONS
-    answer.append(QFile::decodeName(file->d_name));
+        answer.append(QFile::decodeName(file->d_name));
 #if defined(QT_THREAD_SUPPORT) && defined(_POSIX_THREAD_SAFE_FUNCTIONS) && !defined(Q_OS_CYGWIN)
     delete u;
 #endif
