@@ -16,24 +16,29 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include <config-kpa-exiv2.h>
 #include "ImageSearchInfo.h"
-#include "ValueCategoryMatcher.h"
+
+#include <QDebug>
+#include <QRegExp>
+#include <QApplication>
+
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+
+#include <ImageManager/RawImageDecoder.h>
+#include <Settings/SettingsData.h>
+
+#include "AndCategoryMatcher.h"
+#include "CategoryMatcher.h"
+#include "ContainerCategoryMatcher.h"
 #include "ExactCategoryMatcher.h"
+#include "ImageDB.h"
 #include "NegationCategoryMatcher.h"
 #include "NoTagCategoryMatcher.h"
-#include "AndCategoryMatcher.h"
-#include "ContainerCategoryMatcher.h"
 #include "OrCategoryMatcher.h"
-#include <qregexp.h>
-#include "Settings/SettingsData.h"
-#include <klocale.h>
-#include <kdebug.h>
-#include "CategoryMatcher.h"
-#include "ImageDB.h"
-#include <kapplication.h>
-#include <config-kpa-exiv2.h>
-#include <kconfiggroup.h>
-#include "ImageManager/RawImageDecoder.h"
+#include "ValueCategoryMatcher.h"
 using namespace DB;
 
 ImageSearchInfo::ImageSearchInfo( const ImageDate& date,
@@ -281,14 +286,14 @@ QString ImageSearchInfo::toString() const
 void ImageSearchInfo::debug()
 {
     for( QMap<QString,QString>::Iterator it= m_categoryMatchText.begin(); it != m_categoryMatchText.end(); ++it ) {
-        kDebug() << it.key() << ", " << it.value();
+        qDebug() << it.key() << ", " << it.value();
     }
 }
 
 // PENDING(blackie) move this into the Options class instead of having it here.
 void ImageSearchInfo::saveLock() const
 {
-    KConfigGroup config = KGlobal::config()->group( Settings::SettingsData::instance()->groupForDatabase( "Privacy Settings"));
+    KConfigGroup config = KSharedConfig::openConfig()->group( Settings::SettingsData::instance()->groupForDatabase( "Privacy Settings"));
     config.writeEntry( QString::fromLatin1("label"), m_label );
     config.writeEntry( QString::fromLatin1("description"), m_description );
     config.writeEntry( QString::fromLatin1("categories"), m_categoryMatchText.keys() );
@@ -300,7 +305,7 @@ void ImageSearchInfo::saveLock() const
 
 ImageSearchInfo ImageSearchInfo::loadLock()
 {
-    KConfigGroup config = KGlobal::config()->group( Settings::SettingsData::instance()->groupForDatabase( "Privacy Settings" ));
+    KConfigGroup config = KSharedConfig::openConfig()->group( Settings::SettingsData::instance()->groupForDatabase( "Privacy Settings" ));
     ImageSearchInfo info;
     info.m_label = config.readEntry( "label" );
     info.m_description = config.readEntry( "description" );
