@@ -1,5 +1,5 @@
-/* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>
-  
+/* Copyright 2012-2016 Jesper K. Pedersen <blackie@kde.org>
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
@@ -7,43 +7,48 @@
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QScrollArea>
+#include <QVBoxLayout>
+#include <QLabel>
+#include <QRadioButton>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QDebug>
+
+#include <KLocalizedString>
+
 #include "DuplicateMerger.h"
+#include "DuplicateMatch.h"
+#include "MergeToolTip.h"
+#include "Utilities/ShowBusyCursor.h"
+#include "Utilities/DeleteFiles.h"
 #include "DB/ImageDB.h"
 #include "DB/FileName.h"
 #include "DB/FileNameList.h"
 #include "DB/ImageInfo.h"
 #include "DB/MD5.h"
-#include <QScrollArea>
-#include <QVBoxLayout>
-#include "DuplicateMatch.h"
-#include <KLocale>
-#include <QLabel>
-#include "Utilities/ShowBusyCursor.h"
-#include "MergeToolTip.h"
-#include <QRadioButton>
-#include "Utilities/DeleteFiles.h"
 
 namespace MainWindow {
 
-DuplicateMerger::DuplicateMerger(QWidget *parent) :
-    KDialog(parent)
+DuplicateMerger::DuplicateMerger(QWidget *parent) : QDialog(parent)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     resize(800,600);
 
     QWidget* top = new QWidget(this);
     QVBoxLayout* topLayout = new QVBoxLayout(top);
-    setMainWidget(top);
+    setLayout(topLayout);
+    topLayout->addWidget(top);
 
     QString txt = i18n("<p>Below is a list of all images that are duplicate in your database.<br/>"
                        "Select which you want merged, and which of the duplicates should be kept.<br/>"
@@ -76,12 +81,20 @@ DuplicateMerger::DuplicateMerger(QWidget *parent) :
     m_selectionCount = new QLabel;
     topLayout->addWidget(m_selectionCount);
 
-    setButtons(Ok|Cancel|User1|User2);
-    setButtonText(User1, i18n("Select &All"));
-    setButtonText(User2, i18n("Select &None"));
-    connect(this, SIGNAL(user1Clicked()), this, SLOT(selectAll()));
-    connect(this, SIGNAL(user2Clicked()), this, SLOT(selectNone()));
-    connect(this, SIGNAL(okClicked()), this, SLOT(go()));
+    QDialogButtonBox* buttonBox = new QDialogButtonBox();
+
+    m_selectAllButton = buttonBox->addButton(i18n("Select &All"), QDialogButtonBox::YesRole);
+    m_selectNoneButton = buttonBox->addButton(i18n("Select &None"), QDialogButtonBox::NoRole);
+    m_okButton = buttonBox->addButton(QDialogButtonBox::Ok);
+    m_cancelButton = buttonBox->addButton(QDialogButtonBox::Cancel);
+
+    connect(m_selectAllButton, SIGNAL(clicked()), this, SLOT(selectAll()));
+    connect(m_selectNoneButton, SIGNAL(clicked()), this, SLOT(selectNone()));
+    connect(m_okButton, SIGNAL(clicked()), this, SLOT(go()));
+    connect(m_cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+
+    topLayout->addWidget(buttonBox);
+
     findDuplicates();
 }
 
@@ -103,31 +116,39 @@ void DuplicateMerger::selectNone()
 void DuplicateMerger::go()
 {
     Utilities::DeleteMethod method = Utilities::BlockFromDatabase;
-    if (m_trash->isChecked())
+
+    if (m_trash->isChecked()) {
         method = Utilities::MoveToTrash;
-    else if (m_deleteFromDisk->isChecked())
+    } else if (m_deleteFromDisk->isChecked()) {
         method = Utilities::DeleteFromDisk;
+    }
+
     Q_FOREACH( DuplicateMatch* selector, m_selectors) {
         selector->execute(method);
     }
+
+    accept();
 }
 
 void DuplicateMerger::updateSelectionCount()
 {
     int total = 0;
     int selected = 0;
+
     Q_FOREACH( DuplicateMatch* selector, m_selectors) {
         ++total;
         if (selector->selected())
             ++selected;
     }
-    m_selectionCount->setText(i18n("%1 of %2 selected", selected, total));
 
+    m_selectionCount->setText(i18n("%1 of %2 selected", selected, total));
+    m_okButton->setEnabled(selected > 0);
 }
 
 void DuplicateMerger::findDuplicates()
 {
     Utilities::ShowBusyCursor dummy;
+
     Q_FOREACH( const DB::FileName& fileName, DB::ImageDB::instance()->images() ) {
         const DB::ImageInfoPtr info = DB::ImageDB::instance()->info(fileName);
         const DB::MD5 md5 = info->MD5Sum();
@@ -135,15 +156,19 @@ void DuplicateMerger::findDuplicates()
     }
 
     bool anyFound = false;
-    for (QMap<DB::MD5, DB::FileNameList>::const_iterator it = m_matches.constBegin(); it != m_matches.constEnd(); ++it) {
-        if ( it.value().count() > 1 ) {
+    for (QMap<DB::MD5, DB::FileNameList>::const_iterator it = m_matches.constBegin();
+         it != m_matches.constEnd(); ++it)
+    {
+        if (it.value().count() > 1) {
             addRow(it.key());
             anyFound = true;
         }
     }
 
-    if ( !anyFound )
+    if (! anyFound) {
         tellThatNoDuplicatesWereFound();
+    }
+
     updateSelectionCount();
 }
 
@@ -170,12 +195,13 @@ void DuplicateMerger::tellThatNoDuplicatesWereFound()
     label->setFont(fnt);
     m_scrollLayout->addWidget(label);
 
-    enableButton(User1, false);
-    enableButton(User2, false);
-    enableButton(Cancel, false);
+    m_selectAllButton->setEnabled(false);
+    m_selectNoneButton->setEnabled(false);
+    m_okButton->setEnabled(false);
 }
 
 } // namespace MainWindow
 
 #include "DuplicateMerger.moc"
+
 // vi:expandtab:tabstop=4 shiftwidth=4:
