@@ -17,25 +17,29 @@
 */
 
 #include "ExternalPopup.h"
-#include "DB/ImageInfo.h"
-#include <ktrader.h>
-#include <qstringlist.h>
-#include <qlabel.h>
-#include <QPixmap>
+
+#include <QDebug>
 #include <QFile>
-#include <kservice.h>
-#include <kurl.h>
-#include <krun.h>
-#include <kshell.h>
-#include <klocale.h>
-#include <kfileitem.h>
-#include <kdialog.h>
-#include <kdebug.h>
+#include <QIcon>
+#include <QLabel>
+#include <QMimeDatabase>
+#include <QPixmap>
+#include <QStringList>
+#include <QUrl>
+
+#include <KFileItem>
+#include <KLocalizedString>
 #include <KMimeTypeTrader>
-#include <KIcon>
-#include "Window.h"
-#include "RunDialog.h"
+#include <KRun>
+#include <KService>
+#include <KShell>
+
 #include <DB/FileNameList.h>
+#include <DB/ImageInfo.h>
+#include <Settings/SettingsData.h>
+
+#include "RunDialog.h"
+#include "Window.h"
 
 void MainWindow::ExternalPopup::populate( DB::ImageInfoPtr current, const DB::FileNameList& imageList )
 {
@@ -66,7 +70,7 @@ void MainWindow::ExternalPopup::populate( DB::ImageInfoPtr current, const DB::Fi
         for ( OfferType::const_iterator offerIt = offers.begin(); offerIt != offers.end(); ++offerIt ) {
             action = submenu->addAction( (*offerIt).first );
             action->setObjectName( (*offerIt).first ); // Notice this is needed to find the application later!
-            action->setIcon( KIcon((*offerIt).second) );
+            action->setIcon( QIcon::fromTheme((*offerIt).second) );
             action->setData( which );
             action->setEnabled( enabled );
         }
@@ -74,7 +78,7 @@ void MainWindow::ExternalPopup::populate( DB::ImageInfoPtr current, const DB::Fi
         // A personal command
         action = submenu->addAction( i18n("Open With...") );
         action->setObjectName( i18n("Open With...") ); // Notice this is needed to find the application later!
-        // XXX: action->setIcon( KIcon((*offerIt).second) );
+        // XXX: action->setIcon( QIcon::fromTheme((*offerIt).second) );
         action->setData( which );
         action->setEnabled( enabled );
 
@@ -82,7 +86,7 @@ void MainWindow::ExternalPopup::populate( DB::ImageInfoPtr current, const DB::Fi
         // XXX: see kdialog.h for simple usage
         action = submenu->addAction( i18n("Your Command Line") );
         action->setObjectName( i18n("Your Command Line") ); // Notice this is needed to find the application later!
-        // XXX: action->setIcon( KIcon((*offerIt).second) );
+        // XXX: action->setIcon( QIcon::fromTheme((*offerIt).second) );
         action->setData( which );
         action->setEnabled( enabled );
     }
@@ -94,7 +98,7 @@ void MainWindow::ExternalPopup::slotExecuteService( QAction* action )
     const StringSet apps =m_appToMimeTypeMap[name];
 
     // get the list of arguments
-    KUrl::List lst;
+    QList<QUrl> lst;
 
     if ( action->data() == -1 )
     {
@@ -103,7 +107,7 @@ void MainWindow::ExternalPopup::slotExecuteService( QAction* action )
         Q_FOREACH(const DB::FileName &file, m_list )
         {
             if ( m_appToMimeTypeMap[name].contains( mimeType(file) ) )
-                lst.append( KUrl(file.absolute()) );
+                lst.append( QUrl(file.absolute()) );
         }
     } else if (action->data() == 2) {
         QString origFile = m_currentInfo->fileName().absolute();
@@ -119,14 +123,14 @@ void MainWindow::ExternalPopup::slotExecuteService( QAction* action )
         if (origRegexpString.length() > 0) {
             newFile.replace(origRegexp, copyFileReplacement);
             QFile::copy(origFile, newFile);
-            lst.append( newFile );
+            lst.append( QUrl::fromLocalFile(newFile) );
         } else {
             qWarning("No settings were appropriate for modifying the file name (you must fill in the regexp field; Opening the original instead");
-            lst.append( origFile );
+            lst.append( QUrl::fromLocalFile(origFile) );
         }
 
     } else {
-        lst.append( KUrl(m_currentInfo->fileName().absolute()));
+        lst.append( QUrl(m_currentInfo->fileName().absolute()));
     }
 
 
@@ -153,19 +157,20 @@ void MainWindow::ExternalPopup::slotExecuteService( QAction* action )
                                                             QString::fromLatin1("Name == '%1'").arg(name));
     Q_ASSERT( offers.count() >= 1 );
     KService::Ptr ptr = offers.first();
-    KRun::run(*ptr, lst, MainWindow::Window::theMainWindow() );
+    KRun::runService(*ptr, lst, MainWindow::Window::theMainWindow() );
 }
 
 MainWindow::ExternalPopup::ExternalPopup( QWidget* parent )
     :QMenu( parent )
 {
     setTitle( i18n("Invoke External Program") );
-    connect( this, SIGNAL(triggered(QAction*)), this, SLOT(slotExecuteService(QAction*)) );
+    connect(this, &ExternalPopup::triggered, this, &ExternalPopup::slotExecuteService);
 }
 
 QString MainWindow::ExternalPopup::mimeType( const DB::FileName& file )
 {
-    return KMimeType::findByPath(file.absolute(), 0, true)->name();
+    QMimeDatabase db;
+    return db.mimeTypeForFile(file.absolute(), QMimeDatabase::MatchExtension).name();
 }
 
 Utilities::StringSet MainWindow::ExternalPopup::mimeTypes( const DB::FileNameList& files )
