@@ -18,48 +18,53 @@
 
 #ifndef MAINWINDOW_WINDOW_H
 #define MAINWINDOW_WINDOW_H
-class BreadcrumbViewer;
-class KToggleAction;
+#include <config-kpa-kipi.h>
+
+#include <QList>
+#include <QPointer>
+#include <QUrl>
+
+#include <KXmlGuiWindow>
+
+#include <DB/Category.h>
+#include <DB/FileNameList.h>
+#include <DB/ImageSearchInfo.h>
+#include <ThumbnailView/enums.h>
+
+class QAction;
+class QCloseEvent;
+class QContextMenuEvent;
+class QFrame;
+class QLabel;
+class QMoveEvent;
+class QResizeEvent;
 class QStackedWidget;
 class QTimer;
-class KTipDialog;
-class QLabel;
+
 class KActionMenu;
+class KTipDialog;
+class KToggleAction;
 
-#include <Browser/BreadcrumbList.h>
-#include <QContextMenuEvent>
-#include <QMoveEvent>
-#include <QCloseEvent>
-#include <QResizeEvent>
-#include <QLabel>
-#include <KAction>
-#include "DB/ImageInfoList.h"
-#include <kmainwindow.h>
-#include "Settings/SettingsData.h"
-#include <kurl.h>
-#include <kxmlguiwindow.h>
-#include <QPointer>
-#include <config-kpa-kipi.h>
 #ifdef HASKIPI
-#  include <libkipi/version.h>
-#  include <libkipi/pluginloader.h>
+namespace KIPI { class PluginLoader; }
 #endif
-#include "DB/FileNameList.h"
-#include "ThumbnailView/enums.h"
 
-namespace Plugins { class Interface; }
-namespace ThumbnailView { class ThumbnailFacade; }
-namespace Browser{ class BrowserWidget; }
 namespace AnnotationDialog { class Dialog; }
-namespace Settings { class SettingsDialog; }
+namespace Browser{ class BrowserWidget; class BreadcrumbList; }
 namespace DateBar { class DateBarWidget; }
+namespace DB { class ImageInfoList; }
 namespace HTMLGenerator { class HTMLDialog; }
+namespace Plugins { class Interface; }
+namespace Settings { class SettingsDialog; }
+namespace ThumbnailView { class ThumbnailFacade; }
+
+class BreadcrumbViewer;
 
 namespace MainWindow
 {
 class DeleteDialog;
-class TokenEditor;
 class StatusBar;
+class TokenEditor;
 
 class Window :public KXmlGuiWindow
 {
@@ -81,6 +86,7 @@ public slots:
     void showThumbNails(const DB::FileNameList& items);
     void loadPlugins();
     void reloadThumbnails( ThumbnailView::SelectionUpdateMethod method = ThumbnailView::MaintainSelection );
+    void runDemo();
     void slotImageRotated(const DB::FileName& fileName);
     void slotSave();
 
@@ -109,7 +115,6 @@ protected slots:
     void showBrowser();
     void slotOptionGroupChanged();
     void showTipOfDay();
-    void runDemo();
     void lockToDefaultScope();
     void setDefaultScopePositive();
     void setDefaultScopeNegative();
@@ -130,7 +135,7 @@ protected slots:
     void slotExport();
     void delayedInit();
     void slotReenableMessages();
-    void slotImagesChanged( const KUrl::List& );
+    void slotImagesChanged( const QList<QUrl>& );
     void slotSelectionChanged(int count);
     void plug();
     void slotRemoveTokens();
@@ -196,45 +201,45 @@ private:
     QTimer* m_autoSaveTimer;
     Browser::BrowserWidget* m_browser;
     DeleteDialog* m_deleteDialog;
-    KAction* m_lock;
-    KAction* m_unlock;
-    KAction* m_setDefaultPos;
-    KAction* m_setDefaultNeg;
-    KAction* m_jumpToContext;
+    QAction* m_lock;
+    QAction* m_unlock;
+    QAction* m_setDefaultPos;
+    QAction* m_setDefaultNeg;
+    QAction* m_jumpToContext;
     HTMLGenerator::HTMLDialog* m_htmlDialog;
-    KAction* m_configOneAtATime;
-    KAction* m_configAllSimultaniously;
-    KAction* m_createImageStack;
-    KAction* m_unStackImages;
-    KAction* m_setStackHead;
-    KAction* m_view;
-    KAction* m_rotLeft;
-    KAction* m_rotRight;
-    KAction* m_sortByDateAndTime;
-    KAction* m_sortAllByDateAndTime;
-    KAction* m_AutoStackImages;
-    KAction* m_viewInNewWindow;
+    QAction* m_configOneAtATime;
+    QAction* m_configAllSimultaniously;
+    QAction* m_createImageStack;
+    QAction* m_unStackImages;
+    QAction* m_setStackHead;
+    QAction* m_view;
+    QAction* m_rotLeft;
+    QAction* m_rotRight;
+    QAction* m_sortByDateAndTime;
+    QAction* m_sortAllByDateAndTime;
+    QAction* m_AutoStackImages;
+    QAction* m_viewInNewWindow;
     KActionMenu* m_viewMenu;
     KToggleAction* m_smallListView;
     KToggleAction* m_largeListView;
     KToggleAction* m_largeIconView;
-    KAction* m_generateHtml;
-    KAction* m_copy;
-    KAction* m_paste;
-    KAction* m_deleteSelected;
-    KAction* m_limitToMarked;
-    KAction* m_selectAll;
-    KAction* m_runSlideShow;
-    KAction* m_runRandomSlideShow;
+    QAction* m_generateHtml;
+    QAction* m_copy;
+    QAction* m_paste;
+    QAction* m_deleteSelected;
+    QAction* m_limitToMarked;
+    QAction* m_selectAll;
+    QAction* m_runSlideShow;
+    QAction* m_runRandomSlideShow;
     Plugins::Interface* m_pluginInterface;
-    KAction* m_showExifDialog;
+    QAction* m_showExifDialog;
 #ifdef HASKIPI
     KIPI::PluginLoader* m_pluginLoader;
 #endif
-    KAction* m_recreateThumbnails;
-    KAction* m_useNextVideoThumbnail;
-    KAction* m_usePreviousVideoThumbnail;
-    KAction* m_markUntagged;
+    QAction* m_recreateThumbnails;
+    QAction* m_useNextVideoThumbnail;
+    QAction* m_usePreviousVideoThumbnail;
+    QAction* m_markUntagged;
     TokenEditor* m_tokenEditor;
     DateBar::DateBarWidget* m_dateBar;
     QFrame* m_dateBarLine;
