@@ -19,50 +19,42 @@
 #include "ViewerWidget.h"
 #include <config-kpa-exiv2.h>
 
-#include <qapplication.h>
+#include <QAction>
+#include <QApplication>
 #include <QContextMenuEvent>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDesktopWidget>
-#include <qeventloop.h>
-#include <qfileinfo.h>
+#include <QEventLoop>
+#include <QFileDialog>
+#include <QFileInfo>
 #include <qglobal.h>
 #include <QKeyEvent>
 #include <QList>
+#include <QPushButton>
 #include <QResizeEvent>
 #include <QStackedWidget>
 #include <QTimeLine>
 #include <QTimer>
-#include <QVBoxLayout>
 #include <QWheelEvent>
 
 #include <KActionCollection>
-#include <kaction.h>
-#include <kdebug.h>
-#include <kdeversion.h>
-#include <KFileDialog>
-#include <kiconloader.h>
-#include <kio/copyjob.h>
-#include <klocale.h>
-#include <KMessageBox>
-#include <KProcess>
-#include <KPushButton>
-#include <KStandardAction>
-#include <KStandardDirs>
-#include <kwindowsystem.h>
+#include <KIconLoader>
+#include <KIO/CopyJob>
+#include <KLocalizedString>
 
-#include "DB/CategoryCollection.h"
-#include "DB/ImageDB.h"
+#include <DB/CategoryCollection.h>
+#include <DB/ImageDB.h>
 #ifdef HAVE_EXIV2
-#  include "Exif/InfoDialog.h"
+#  include <Exif/InfoDialog.h>
 #endif
-#include "ImageManager/ThumbnailCache.h"
-#include "MainWindow/CategoryImagePopup.h"
-#include "MainWindow/DeleteDialog.h"
-#include "MainWindow/DirtyIndicator.h"
-#include "MainWindow/ExternalPopup.h"
-#include "MainWindow/Window.h"
-#include "Utilities/Util.h"
+#include <ImageManager/ThumbnailCache.h>
+#include <MainWindow/CategoryImagePopup.h>
+#include <MainWindow/DeleteDialog.h>
+#include <MainWindow/DirtyIndicator.h>
+#include <MainWindow/ExternalPopup.h>
+#include <MainWindow/Window.h>
+#include <Utilities/Util.h>
 
 #include "CategoryImageConfig.h"
 #include "ImageDisplay.h"
@@ -112,10 +104,10 @@ Viewer::ViewerWidget::ViewerWidget( UsageType type, QMap<Qt::Key, QPair<QString,
 
     createVideoViewer();
 
-    connect( m_imageDisplay, SIGNAL(possibleChange()), this, SLOT(updateCategoryConfig()) );
-    connect( m_imageDisplay, SIGNAL(imageReady()), this, SLOT(updateInfoBox()) );
-    connect( m_imageDisplay, SIGNAL(setCaptionInfo(QString)), this, SLOT(setCaptionWithDetail(QString)) );
-    connect( m_imageDisplay, SIGNAL(viewGeometryChanged(QSize,QRect,double)), this, SLOT(remapAreas(QSize,QRect,double)) );
+    connect(m_imageDisplay, &ImageDisplay::possibleChange, this, &ViewerWidget::updateCategoryConfig);
+    connect(m_imageDisplay, &ImageDisplay::imageReady, this, &ViewerWidget::updateInfoBox);
+    connect(m_imageDisplay, &ImageDisplay::setCaptionInfo, this, &ViewerWidget::setCaptionWithDetail);
+    connect(m_imageDisplay, &ImageDisplay::viewGeometryChanged, this, &ViewerWidget::remapAreas);
 
     // This must not be added to the layout, as it is standing on top of
     // the ImageDisplay
@@ -127,7 +119,7 @@ Viewer::ViewerWidget::ViewerWidget( UsageType type, QMap<Qt::Key, QPair<QString,
     m_slideShowTimer = new QTimer( this );
     m_slideShowTimer->setSingleShot( true );
     m_slideShowPause = Settings::SettingsData::instance()->slideShowInterval() * 1000;
-    connect( m_slideShowTimer, SIGNAL(timeout()), this, SLOT(slotSlideShowNextFromTimer()) );
+    connect(m_slideShowTimer, &QTimer::timeout, this, &ViewerWidget::slotSlideShowNextFromTimer);
     m_speedDisplay = new SpeedDisplay( this );
     m_speedDisplay->hide();
 
@@ -152,7 +144,7 @@ void Viewer::ViewerWidget::setupContextMenu()
     createCategoryImageMenu();
     createFilterMenu();
 
-    KAction* action = m_actions->addAction( QString::fromLatin1("viewer-edit-image-properties"), this, SLOT(editImage()) );
+    QAction * action = m_actions->addAction( QString::fromLatin1("viewer-edit-image-properties"), this, SLOT(editImage()) );
     action->setText( i18nc("@action:inmenu","Annotate...") );
     action->setShortcut( Qt::CTRL+Qt::Key_1 );
     m_popup->addAction( action );
@@ -191,7 +183,7 @@ void Viewer::ViewerWidget::setupContextMenu()
 void Viewer::ViewerWidget::createShowContextMenu()
 {
     VisibleOptionsMenu* menu = new VisibleOptionsMenu( this, m_actions );
-    connect( menu, SIGNAL(visibleOptionsChanged()), this, SLOT(updateInfoBox()) );
+    connect(menu, &VisibleOptionsMenu::visibleOptionsChanged, this, &ViewerWidget::updateInfoBox);
     m_popup->addMenu( menu );
 }
 
@@ -202,7 +194,7 @@ void Viewer::ViewerWidget::createWallPaperMenu()
     m_wallpaperMenu = new QMenu( m_popup );
     m_wallpaperMenu->setTitle( i18nc("@title:inmenu","Set as Wallpaper") );
 
-    KAction* action = m_actions->addAction( QString::fromLatin1("viewer-centered"), this, SLOT(slotSetWallpaperC()) );
+    QAction * action = m_actions->addAction( QString::fromLatin1("viewer-centered"), this, SLOT(slotSetWallpaperC()) );
     action->setText( i18nc("@action:inmenu","Centered") );
     m_wallpaperMenu->addAction(action);
 
@@ -263,7 +255,7 @@ void Viewer::ViewerWidget::createInvokeExternalMenu()
 {
     m_externalPopup = new MainWindow::ExternalPopup( m_popup );
     m_popup->addMenu( m_externalPopup );
-    connect( m_externalPopup, SIGNAL(aboutToShow()), this, SLOT(populateExternalPopup()) );
+    connect(m_externalPopup, &MainWindow::ExternalPopup::aboutToShow, this, &ViewerWidget::populateExternalPopup);
 }
 
 void Viewer::ViewerWidget::createRotateMenu()
@@ -271,7 +263,7 @@ void Viewer::ViewerWidget::createRotateMenu()
     m_rotateMenu = new QMenu( m_popup );
     m_rotateMenu->setTitle( i18nc("@title:inmenu","Rotate") );
 
-    KAction* action = m_actions->addAction( QString::fromLatin1("viewer-rotate90"), this, SLOT(rotate90()) );
+    QAction * action = m_actions->addAction( QString::fromLatin1("viewer-rotate90"), this, SLOT(rotate90()) );
     action->setText( i18nc("@action:inmenu","Rotate clockwise") );
     action->setShortcut( Qt::Key_9 );
     m_rotateMenu->addAction( action );
@@ -295,7 +287,7 @@ void Viewer::ViewerWidget::createSkipMenu()
     QMenu *popup = new QMenu( m_popup );
     popup->setTitle( i18nc("@title:inmenu As in 'skip 2 images'","Skip") );
 
-    KAction* action = m_actions->addAction( QString::fromLatin1("viewer-home"), this, SLOT(showFirst()) );
+    QAction * action = m_actions->addAction( QString::fromLatin1("viewer-home"), this, SLOT(showFirst()) );
     action->setText( i18nc("@action:inmenu Go to first image","First") );
     action->setShortcut( Qt::Key_Home );
     popup->addAction( action );
@@ -309,11 +301,7 @@ void Viewer::ViewerWidget::createSkipMenu()
 
     action = m_actions->addAction( QString::fromLatin1("viewer-next"), this, SLOT(showNext()) );
     action->setText( i18nc("@action:inmenu","Show Next") );
-    action->setShortcut( Qt::Key_PageDown );
-    // bah, they don't use references
-    KShortcut viewerNextShortcut = action->shortcut();
-    viewerNextShortcut.setAlternate( Qt::Key_Space );
-    action->setShortcut( viewerNextShortcut );
+    action->setShortcuts(QList<QKeySequence>() << Qt::Key_PageDown << Qt::Key_Space);
     popup->addAction( action );
     m_forwardActions.append(action);
 
@@ -337,10 +325,7 @@ void Viewer::ViewerWidget::createSkipMenu()
 
     action = m_actions->addAction( QString::fromLatin1("viewer-prev"), this, SLOT(showPrev()) );
     action->setText( i18nc("@action:inmenu","Show Previous") );
-    action->setShortcut( Qt::Key_PageUp );
-    KShortcut viewerPrevShortcut = action->shortcut();
-    viewerPrevShortcut.setAlternate(Qt::Key_Backspace);
-    action->setShortcut(viewerPrevShortcut);
+    action->setShortcuts(QList<QKeySequence>() << Qt::Key_PageUp << Qt::Key_Backspace);
     popup->addAction( action );
     m_backwardActions.append(action);
 
@@ -381,7 +366,7 @@ void Viewer::ViewerWidget::createZoomMenu()
     popup->setTitle( i18nc("@action:inmenu","Zoom") );
 
     // PENDING(blackie) Only for image display?
-    KAction* action = m_actions->addAction( QString::fromLatin1("viewer-zoom-in"), this, SLOT(zoomIn()) );
+    QAction * action = m_actions->addAction( QString::fromLatin1("viewer-zoom-in"), this, SLOT(zoomIn()) );
     action->setText( i18nc("@action:inmenu","Zoom In") );
     action->setShortcut( Qt::Key_Plus );
     popup->addAction( action );
@@ -492,9 +477,9 @@ void Viewer::ViewerWidget::load()
     setCaptionWithDetail( QString() );
 
     // PENDING(blackie) This needs to be improved, so that it shows the actions only if there are that many images to jump.
-    for( QList<KAction*>::const_iterator it = m_forwardActions.constBegin(); it != m_forwardActions.constEnd(); ++it )
+    for( QList<QAction *>::const_iterator it = m_forwardActions.constBegin(); it != m_forwardActions.constEnd(); ++it )
         (*it)->setEnabled( m_current +1 < (int) m_list.count() );
-    for( QList<KAction*>::const_iterator it = m_backwardActions.constBegin(); it != m_backwardActions.constEnd(); ++it )
+    for( QList<QAction *>::const_iterator it = m_backwardActions.constBegin(); it != m_backwardActions.constEnd(); ++it )
         (*it)->setEnabled( m_current > 0 );
 
     m_setStackHead->setEnabled( currentInfo()->isStacked() );
@@ -1329,7 +1314,7 @@ void Viewer::ViewerWidget::createVideoMenu()
             menu->addAction(sep);
         }
 
-        KAction* seek = m_actions->addAction( QString::fromLatin1(info.name), m_videoDisplay, SLOT(seek()));
+        QAction * seek = m_actions->addAction( QString::fromLatin1(info.name), m_videoDisplay, SLOT(seek()));
         seek->setText(info.title);
         seek->setData(info.value);
         seek->setShortcut( info.key );
@@ -1359,7 +1344,7 @@ void Viewer::ViewerWidget::createVideoMenu()
     m_popup->addAction(m_makeThumbnailImage);
     m_videoActions.append(m_makeThumbnailImage);
 
-    KAction* restart = m_actions->addAction( QString::fromLatin1("viewer-video-restart"), m_videoDisplay, SLOT(restart()) );
+    QAction * restart = m_actions->addAction( QString::fromLatin1("viewer-video-restart"), m_videoDisplay, SLOT(restart()) );
     restart->setText( i18nc("@action:inmenu Restart video playback.","Restart") );
     m_popup->addAction( restart );
     m_videoActions.append( restart );
@@ -1369,7 +1354,7 @@ void Viewer::ViewerWidget::createCategoryImageMenu()
 {
     m_categoryImagePopup = new MainWindow::CategoryImagePopup( m_popup );
     m_popup->addMenu( m_categoryImagePopup );
-    connect( m_categoryImagePopup, SIGNAL(aboutToShow()), this, SLOT(populateCategoryImagePopup()) );
+    connect(m_categoryImagePopup, &MainWindow::CategoryImagePopup::aboutToShow, this, &ViewerWidget::populateCategoryImagePopup);
 }
 
 void Viewer::ViewerWidget::createFilterMenu()
@@ -1411,7 +1396,7 @@ void Viewer::ViewerWidget::test()
     QTimeLine* timeline = new QTimeLine;
     timeline->setStartFrame( _infoBox->y() );
     timeline->setEndFrame( height() );
-    connect( timeline, SIGNAL(frameChanged(int)), this, SLOT(moveInfoBox(int)) );
+    connect(timeline, &QTimeLine::frameChanged, this, &ViewerWidget::moveInfoBox);
     timeline->start();
 #endif // TESTING
 }
@@ -1425,7 +1410,7 @@ void Viewer::ViewerWidget::createVideoViewer()
 {
     m_videoDisplay = new VideoDisplay( this );
     addWidget( m_videoDisplay );
-    connect( m_videoDisplay, SIGNAL(stopped()), this, SLOT(videoStopped()) );
+    connect(m_videoDisplay, &VideoDisplay::stopped, this, &ViewerWidget::videoStopped);
 }
 
 void Viewer::ViewerWidget::stopPlayback()
@@ -1465,8 +1450,8 @@ void Viewer::ViewerWidget::addTaggedAreas()
             newArea->setActualGeometry(areaData.value());
             newArea->show();
 
-            connect( m_infoBox, SIGNAL(tagHovered(QPair<QString, QString>)), newArea, SLOT(checkShowArea(QPair<QString, QString>)) );
-            connect( m_infoBox, SIGNAL(noTagHovered()), newArea, SLOT(resetViewStyle()) );
+            connect(m_infoBox, &InfoBox::tagHovered, newArea, &TaggedArea::checkShowArea);
+            connect(m_infoBox, &InfoBox::noTagHovered, newArea, &TaggedArea::resetViewStyle);
         }
     }
 
@@ -1518,7 +1503,7 @@ void Viewer::ViewerWidget::remapAreas(QSize viewSize, QRect zoomWindow, double s
     int innerOffsetLeft = -zoomWindow.left() * scaleWidth;
     int innerOffsetTop = -zoomWindow.top() * scaleHeight;
 
-    foreach (TaggedArea *area, findChildren<TaggedArea *>()) {
+    Q_FOREACH(TaggedArea *area, findChildren<TaggedArea *>()) {
         QRect actualGeometry = area->actualGeometry();
         QRect screenGeometry;
 
@@ -1535,20 +1520,27 @@ void Viewer::ViewerWidget::remapAreas(QSize viewSize, QRect zoomWindow, double s
 
 void Viewer::ViewerWidget::copyTo()
 {
-    KUrl src = KUrl::fromPath(currentInfo()->fileName().absolute());
-
-    // "kfiledialog:///copyTo" -> use last directory that was used in this dialog
-    KFileDialog dialog( KUrl("kfiledialog:///copyTo"), QString() /* empty filter */, this );
-    dialog.setCaption( i18nc("@title:window", "Copy image to...") );
-    dialog.okButton()->setText( i18nc("@action:button", "Copy") );
-    dialog.setSelection(src.fileName());
-    dialog.setMode(KFile::File | KFile::Directory);
-
-    if (! dialog.exec()) {
-        return;
+    QUrl src = QUrl::fromLocalFile(currentInfo()->fileName().absolute());
+    if (m_lastCopyToTarget.isNull()) {
+        // get directory of src file
+        m_lastCopyToTarget = QFileInfo(src.path()).path();
     }
 
-    KIO::copy(src, dialog.selectedUrl());
+    QFileDialog dialog( this );
+    dialog.setWindowTitle( i18nc("@title:window", "Copy image to...") );
+    // use directory of src as start-location:
+    dialog.setDirectory(m_lastCopyToTarget);
+    dialog.selectFile(src.fileName());
+    dialog.setAcceptMode(QFileDialog::AcceptSave);
+    dialog.setLabelText(QFileDialog::Accept, i18nc("@action:button", "Copy"));
+
+    if (dialog.exec()) {
+        QUrl dst = dialog.selectedUrls().first();
+        KIO::CopyJob *job = KIO::copy(src, dst);
+        connect(job, &KIO::CopyJob::finished, job, &QObject::deleteLater);
+        // get directory of dst file
+        m_lastCopyToTarget = QFileInfo(dst.path()).path();
+    }
 }
 
 #include "ViewerWidget.moc"
